@@ -20,7 +20,7 @@ Copyright (c) 2020, EPFL/Blue Brain Project
 """
 
 import matplotlib
-matplotlib.use('Agg', warn=True)  # noqa
+matplotlib.use('Agg')  # noqa
 import matplotlib.pyplot as plt
 from matplotlib.backends.backend_pdf import PdfPages
 
@@ -31,6 +31,7 @@ import os
 import logging
 import gzip
 import json
+import pprint
 
 from itertools import cycle
 from collections import OrderedDict
@@ -107,18 +108,20 @@ class Extractor(object):
 
         if "tolerance" not in self.options:
             self.options["tolerance"] = 10
-        else:
-            if conv_fact != 1:
-                tolerance = self.options["tolerance"]
-                self.options["tolerance"] = conv_fact * tolerance
 
         if "strict_stiminterval" not in self.options:
             self.options["strict_stiminterval"] = {'base': False}
 
         if isinstance(self.options["tolerance"], list) is False:
+            if conv_fact != 1:
+                tolerance = self.options["tolerance"]
+                self.options["tolerance"] = conv_fact * tolerance
             self.options["tolerance"] =\
                 numpy.ones(len(self.options["target"]))\
                 * self.options["tolerance"]
+        elif conv_fact != 1:
+            self.options["tolerance"] = \
+                [x * conv_fact for x in self.options["tolerance"]]
 
         if "nanmean" not in self.options:
             self.options["nanmean"] = False
@@ -395,6 +398,14 @@ class Extractor(object):
                         right=0.97, hspace=0.75, wspace=0.2)
 
                 for i_plot in range(n_plot):
+                    # reduce figure title length if too long
+                    filename_string = filenames[i_plot]
+                    if len(filename_string) > 50:
+                        filename_fin = filename_string[:18] + ' ... ' + \
+                            filename_string[-18:]
+                    else:
+                        filename_fin = filename_string
+
                     axs[i_plot].plot(
                         ts[i_plot],
                         voltages[i_plot],
@@ -403,7 +414,7 @@ class Extractor(object):
                     axs[i_plot].set_title(
                         cellname + " " + expname + " amp:" +
                         str(amps[i_plot]) +
-                        " file:" + filenames[i_plot])
+                        " file:" + filename_fin)
 
                     axs_c[i_plot].plot(
                         ts[i_plot],
@@ -413,7 +424,7 @@ class Extractor(object):
                     axs_c[i_plot].set_title(
                         cellname + " " + expname + " amp:" +
                         str(amps[i_plot]) +
-                        " file:" + filenames[i_plot])
+                        " file:" + filename_fin)
 
                 # plt.show()
 
@@ -1071,18 +1082,17 @@ class Extractor(object):
                     self.dataset_mean[expname]['n'][feature][str(target)] = n
 
                     if n == 1:  # only result from one cell in population
-                        # pick values from this one
-                        # cell instead if more than one sweep
-                        if len(cell_n) > 1:
-                            self.dataset_mean[expname]['mean_features'][
-                                feature][
-                                str(target)] = feat[0]
-                            self.dataset_mean[expname]['std_features'][
-                                feature][str(target)] = cell_std_feat[0]
-                            [bcmean, bcstd, bcld, bcshift] = \
-                                self.dataset_mean[expname][
-                                'cell_bc_features'][feature][str(
-                                    target)][0]
+                        # pick values from this cell
+                        val_idx = numpy.where(~numpy.isnan(
+                            numpy.atleast_1d(feat)))[0][0]
+                        self.dataset_mean[expname]['mean_features'][
+                            feature][str(target)] = feat[val_idx]
+                        self.dataset_mean[expname]['std_features'][
+                            feature][str(target)] = cell_std_feat[val_idx]
+                        [bcmean, bcstd, bcld, bcshift] = \
+                            self.dataset_mean[expname][
+                            'cell_bc_features'][feature][str(
+                                target)][val_idx]
                     else:
                         self.dataset_mean[expname][
                             'mean_features'][feature][str(
@@ -1278,7 +1288,15 @@ class Extractor(object):
                             s = self.dataset_mean[expname]['std_features'][
                                 feature][
                                 str(target)]
-                            if ~numpy.isnan(m) and ((s > 0.0) or (m == 0.0)):
+
+                            if "zero_std" in self.options and \
+                                    self.options["zero_std"]:
+                                rules = [~numpy.isnan(m)]
+                            else:
+                                rules = [
+                                    ~numpy.isnan(m), (s > 0.0) or
+                                    (m == 0.0)]
+                            if all(rules):
                                 amp_rel_list.append(a)
                                 mean_list.append(m)
                                 std_list.append(s)
@@ -1565,11 +1583,9 @@ class Extractor(object):
                                     str(target)]
 
                                 if boxcox:
-                                    do_add = ~numpy.isnan(bcm) and (
-                                        (bcs > 0.0) or (bcm == 0.0))
+                                    do_add = ~numpy.isnan(bcm)
                                 else:
-                                    do_add = ~numpy.isnan(m) and (
-                                        (s > 0.0) or (m == 0.0))
+                                    do_add = ~numpy.isnan(m)
 
                                 if do_add:
 
@@ -1669,7 +1685,10 @@ class Extractor(object):
 
                                     if 'stimuli' not in stim[stimname]:
 
-                                        totduration = round(tend)
+                                        try:
+                                            totduration = round(tend)
+                                        except ValueError:
+                                            totduration = numpy.NaN
                                         delay = round(
                                             self.options["delay"] + ton)
                                         duration = round(toff - ton)
@@ -1781,12 +1800,22 @@ class Extractor(object):
                     logger.debug(" Adding experiment %s to metadata", expname)
 
                     metadataset_cell_exp[expname] = OrderedDict()
-
-                    for idx_file, filename in enumerate(files):
-                        fullpath = os.path.join(
-                            self.path, cellname, filename + '_' +
-                            'metadata.json')
-                        metadataset_cell_exp[expname][filename] = \
-                            common.manageMetadata.get_metadata(
-                            fullpath)
+                    if self.format == "igor":
+                        for dict_igor in files:
+                            cellname = dict_igor["ordinal"]
+                            foldpath = os.path.dirname(dict_igor["v_file"])
+                            fullpath = os.path.join(
+                                foldpath, cellname + '_' + 'metadata.json')
+                            print(fullpath)
+                            metadataset_cell_exp[expname][cellname] = \
+                                common.manageMetadata.get_metadata(
+                                fullpath)
+                    else:
+                        for idx_file, filename in enumerate(files):
+                            fullpath = os.path.join(
+                                self.path, cellname, filename + '_' +
+                                'metadata.json')
+                            metadataset_cell_exp[expname][filename] = \
+                                common.manageMetadata.get_metadata(
+                                fullpath)
         return True
